@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 from __future__ import unicode_literals, print_function
 import getpass
 import os
@@ -55,6 +55,7 @@ def _cert_info(certdata):
         name=_decode(ci.name()),
         thumb=_decode(hexlify(tc.thumbprint())),
         issuer=_decode(ci.issuer()),
+        subject_id=_decode(hexlify(tc.subject_id())),
         serial=':'.join(hex(ord(x))[2:] for x in
                         reversed(ci.serial())),
     )
@@ -66,6 +67,7 @@ def _ensure(flag, msg, exc=KeysetException):
 
 
 class hdimage(object):
+
     """Incapsulation of keyset stored on hdimage.
     WARNING:
     ----------------------------------------------------------------------
@@ -75,7 +77,7 @@ class hdimage(object):
     """
 
     _names = set(('primary2.key', 'header.key', 'primary.key', 'masks.key',
-                 'masks2.key', 'name.key',))
+                  'masks2.key', 'name.key',))
     _keyspecs = ('AT_SIGNATURE', 'AT_KEYEXCHANGE')
 
     @property
@@ -97,18 +99,20 @@ class hdimage(object):
         self.user = getpass.getuser()
         self.certs = {}
 
-        self.configfile = '/var/opt/cprocsp/users/{0}/local.ini'.format(self.user)
+        self.configfile = '/var/opt/cprocsp/users/{0}/local.ini'.format(
+            self.user)
         self.section = r'KeyDevices\passwords\"{0}"'.format(self.name)
 
         self.broken = False
         self.empty = True
         try:
-            self.ctx = csp.Crypt(self.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_SILENT)
+            self.ctx = csp.Crypt(
+                self.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_SILENT)
         except ValueError:
             try:
                 self.ctx = csp.Crypt(
                     self.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_NEWKEYSET | csp.CRYPT_SILENT)
-            except:
+            except Exception:
                 self.broken = True
                 self.ctx = None
         else:
@@ -121,12 +125,12 @@ class hdimage(object):
                 try:
                     cert = key.extract_cert(csp.AT_KEYEXCHANGE)
                     self.certs['AT_KEYEXCHANGE'] = _cert_info(cert)
-                except:
+                except Exception:
                     pass
                 try:
                     cert = key.extract_cert(csp.AT_SIGNATURE)
                     self.certs['AT_SIGNATURE'] = _cert_info(cert)
-                except:
+                except Exception:
                     pass
 
         if not self.broken:
@@ -138,7 +142,8 @@ class hdimage(object):
                 self.shortcut = None
         if self.shortcut:
             self.folder = self.shortcut.split('\\')[2]
-            self.dirname = '/var/opt/cprocsp/keys/{0}/{1}'.format(self.user, self.folder)
+            self.dirname = '/var/opt/cprocsp/keys/{0}/{1}'.format(
+                self.user, self.folder)
             self.empty = not os.path.exists(self.dirname)
         else:
             self.folder = self.dirname = None
@@ -156,7 +161,8 @@ class hdimage(object):
         cfg = self.config
         if not self.config.has_section(self.section):
             cfg.add_section(self.section)
-            cfg.set(self.section, 'shortcut', '"{0}"'.format(self.shortcut.replace('\\', '\\\\')))
+            cfg.set(self.section, 'shortcut', '"{0}"'.format(
+                self.shortcut.replace('\\', '\\\\')))
             cfg.write(open(self.configfile, 'wt'))
 
     def backup(self, filename):
@@ -181,7 +187,7 @@ class hdimage(object):
                         key = self.ctx.get_key(keyspec)
                         cert = key.extract_cert()
                         zf.writestr('{0}.cer'.format(keyname), cert)
-                    except:
+                    except Exception:
                         continue
                 zf.close()
         return filename
@@ -267,7 +273,8 @@ class hdimage(object):
 
         del res.ctx
         try:
-            res.ctx = csp.Crypt(res.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_SILENT)
+            res.ctx = csp.Crypt(
+                res.cont, csp.PROV_GOST_2001_DH, csp.CRYPT_SILENT)
             if paswd:
                 res.ctx.set_password(str(paswd), csp.AT_KEYEXCHANGE)
                 res.ctx.change_password(str(''))
@@ -305,7 +312,7 @@ class hdimage(object):
                     except ValueError:
                         pass
 
-        except:
+        except Exception:
             cryptoapi.remove_key(res.name)
             raise
         return res
